<?php get_header(); ?>
	
<div class="container">

<?php include('breadcrumb.php') ?>

<div class="row">
<?php get_sidebar(); ?>
<div class="col-md-8 col-lg-8 order-1">
<?php if (have_posts()) : ?>
	<?php while (have_posts()) : the_post(); ?>
    <a href="<?php the_permalink() ?>" ><h1><?php the_title(); ?></h1></a> 
    <div class="card border-0">
        <?php the_content('Read the rest&raquo;'); ?>
        <h4>Solutions Collecting From Web of "<?php the_title(); ?>"</h4>
    <div class="list-group list-group-flush">
    <?php include('relatedposts.php') ?>
    <?php comments_template(); ?>
	</div>
	<?php endwhile; ?>
	<?php else : ?>
	<h2 class="center">Not Found</h2>
		<p class="center">Sorry, but you are looking for something that isn't here.</p>
		<?php get_search_form(); ?>
	<?php endif; ?>

        </div>
<ul>
<?php
$rand_posts = get_posts('numberposts=15&orderby=rand');
foreach( $rand_posts as $post ):
?>
  <li><a href="<?php the_permalink();?>" rel="bookmark">
    <?php the_title(); ?>
  </a></li>
<?php endforeach; ?>
</ul>    
    </div>
    
</div>

<?php get_footer(); ?>