<?php get_header(); ?>
<div class="jumbotron jumbotron-fluid">
     <div class="container">
    <h1 class="display-3">Articles of <?php wp_title(''); ?></h1>
     </div>
</div>
<div class="container">

<div class="row">
<div class="col-md-8 order-2 px-0">
    <div class="card border-0">
    <?php if (have_posts()) : ?>
 <?php while (have_posts()) : the_post(); ?>
            <div class="list-group list-group-flush">
  <a href="<?php the_permalink() ?>" title="<?php the_title(); ?>" class="list-group-item list-group-item-action flex-column align-items-start">
	<div class="media">
    <?php echo catch_that_image(); ?>
  <div class="media-body">
    <h3 class="mb1"><?php the_title(); ?></h3>
    <?php the_excerpt(); ?>
  </div>
</div>
  </a>
			</div>
<?php endwhile; ?>

	</div>
    <nav>
  <?php
   global $wp_query, $wp_rewrite;
   $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;
	echo seanpaginate_links(array(
	'prev_next'          => 1,
	'type'          => 'list',
	'mid_size'           => 15,
	'current' => $current,
));
?>
	</nav>
	<?php else : ?>
	<h2 class="center">Not Found</h2>
		<p class="center">Sorry, but you are looking for something that isn't here.</p>
		<?php get_search_form(); ?>
	<?php endif; ?>
</div>
<?php get_sidebar(); ?>
</div>
<?php get_footer(); ?>