<div class="col-sm-4 d-none d-sm-block"><div class="ml-5">
            <div class="border-top border-primary">
                <div class="border-bottom border-light mb-2">
                    <h5 class="p-2 text-center">24小时快讯</h5>
                </div>
                <div class="pb-3">
                <ul>
                    <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary text-right">5分钟</p></li>
                <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary text-right">5分钟</p></li>
                <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary">5分钟</p></li>
                <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary">5分钟</p></li>
                <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary">5分钟</p></li>
                <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary">5分钟</p></li>
                <li><a href="#" class="text-dark">万科股东大会即将召开：郁亮现身 祝九胜亮相</a><p class="small text-secondary">5分钟</p></li>
                
                </ul>
            
          </div>
            </div>
            <div class="border-top border-primary pb-2">
                <div class="border-bottom border-light mb-2">
                    <h5 class="p-2 text-center">热门文章</h5>
                </div>
<?php
$rand_posts = get_posts('numberposts=15&orderby=rand');

foreach( $rand_posts as $post ):

?>
                <div class=" row border-0 flex-row box-shadow mb-3 m-0">
                    <div class="col-4 d-flex align-items-center p-0 listi2"><img class="" src="<?php echo catch_that_image(); ?>"></div>
                
                    <div class="col-8 d-flex flex-column align-items-start p-2">

                      <h6 class="mb-auto">
                        <a class="text-dark font-weight-bold" href="<?php the_permalink();?>" title="<?php the_title(); ?>"><?php the_title(); ?></a>
                      </h6>
                        <small class="align-self-end text-muted"><?php the_time(); ?></small>
                    </div>

                </div>
<?php endforeach; ?>
                
            </div>  
            <div class="border-top border-primary">
                <div class="border-bottom border-light mb-2">
                    <h5 class="p-2 text-center">美讯网专题</h5>
                </div>
                <a href="#"><div class="card mb-2 border-0">
                    <div class="zt"><img src="http://vcbeat.net/upload/logo/64/49/70/18/5a7d1916f304a.jpg" alt="" class="card-img-top"></div>
            <div class="card-footer text-center text-dark font-weight-bold">医美区块链专题</div>
                    </div></a>
                <a href="#"><div class="card mb-2 border-0">
                    <div class="zt"><img src="http://vcbeat.net/upload/logo/64/49/70/18/5a7d1916f304a.jpg" alt="" class="card-img-top"></div>
            <div class="card-footer text-center text-dark font-weight-bold">医美区块链专题</div>
                    </div></a>
                <a href="#"><div class="card mb-2 border-0">
                    <div class="zt"><img src="http://vcbeat.net/upload/logo/64/49/70/18/5a7d1916f304a.jpg" alt="" class="card-img-top"></div>
            <div class="card-footer text-center text-dark font-weight-bold">医美区块链专题</div>
                    </div></a>
            </div>
        </div></div>