<?php
/*
Template Name: Advertising Page
*/
?>

<?php get_header(); ?>
	
<div class="container">

<?php include('breadcrumb.php') ?>



<div class="row">
<div class="article-content">
<h1>Advertising with <?php bloginfo('name'); ?></h1>
	<p><?php bloginfo('name'); ?> accept these advertising:</p>
<ul>
	<li>Top banner on every page flash or image</li>
	<li>Sidebar banner flash or image</li>
	<li>Bottom banner on every page flash or image</li>
	<li>Bottom TXT-Ads on every single-post page</li>
</ul>
<p>If you are interested in advertising on <?php bloginfo('name'); ?>, you can send your content and price to <a href="/contact/">us</a>.</p>
</div>


</div>


<?php get_footer(); ?>