<?php
/*
Template Name: Topics Page
*/
?>

<?php get_header(); ?>
<div class="jumbotron jumbotron-fluid">
     <div class="container">
    <h1 class="display-3">Topics of <?php bloginfo('name'); ?></h1>
     </div>
</div>
<div class="container">

<div class="row">
<div class="col-md-8 order-2 px-0">


	<?php wp_tag_cloud('smallest=12&largest=48&unit=px&number=1000&order=RAND'); ?>


</div>
<?php get_sidebar(); ?>
</div>
<?php get_footer(); ?>