<div class="row ">
        <div class="col-12">
        <ol class="breadcrumb ">
  <li class="breadcrumb-item"><a href="/"><?php bloginfo('name'); ?></a></li>
  <li class="breadcrumb-item"><?php the_tags("<span class='badge badge-pill badge-light'>","</span> <span class='badge badge-pill badge-light'>","</span>"); ?></li>
  <li class="breadcrumb-item active"><?php the_title(); ?></li>
        </ol></div>
</div>