<div class="jumbotron jumbotron-fluid">
     <div class="container">
  <h1 class="display-5"><?php bloginfo('name'); ?></h1>
  <p><?php bloginfo('description'); ?></p>
<script async src="//pagead2.googlesyndication.com/pagead/js/adsbygoogle.js"></script>
<!-- pc 970*90 -->
<ins class="adsbygoogle"
     style="display:inline-block;width:970px;height:90px"
     data-ad-client="ca-pub-7560617178981988"
     data-ad-slot="7592697257"></ins>
<script>
(adsbygoogle = window.adsbygoogle || []).push({});
</script>
     </div>
</div> 