<?php
/**
 * The template for displaying pages
 *
 * This is the template that displays all pages by default.
 * Please note that this is the WordPress construct of pages and that
 * other "pages" on your WordPress site will use a different template.
 *
 * @package WordPress
 * @subpackage Twenty_Fifteen
 * @since Twenty Fifteen 1.0
 */
 get_header(); ?>
	
<div class="container">

<?php include('banner.php') ?>
<br>
<?php include('breadcrumb.php') ?>



<div class="row">
<div class="col-md-8 article-content">
	<a href="<?php the_permalink() ?>" title="<?php the_title(); ?>" ><h1 class="text-uppercase page-header"><?php the_title(); ?></h1></a>
<address>
  <strong>Sean</strong><br>
  
  <abbr title="Skype">Skype:</abbr> dnv@live.com </br>

  <abbr title="Wechat">WeChat:</abbr> supporter </br>

  <abbr title="Email">Mail:</abbr> <a href="mailto:lansespirit@gmail.com">lansespirit@gmail.com</a></br>
</address>
		
</div>

<?php get_sidebar(); ?>

</div>

<?php include('info.php') ?>

<?php get_footer(); ?>