<div class="col-md-4 order-3">
	<?php if ( is_home() ) { ?>
	<script async src="//pagead2.googlesyndication.com/pagead/js/adsbygoogle.js"></script>
<!-- pc 300*600 -->
<ins class="adsbygoogle"
     style="display:inline-block;width:300px;height:600px"
     data-ad-client="ca-pub-7560617178981988"
     data-ad-slot="7780399513"></ins>
<script>
(adsbygoogle = window.adsbygoogle || []).push({});
</script>
	<?php } ?>
        <div class="card border-0">
            <div class="card-header">Intereting Posts</div>
            <div class="list-group list-group-flush">
        <?php
$rand_posts = get_posts('numberposts=15&orderby=rand');

foreach( $rand_posts as $post ):

?>
  <a href="<?php the_permalink();?>" rel="bookmark" class="list-group-item list-group-item-action">
    <?php the_title(); ?>
  </a>
<?php endforeach; ?>
			</div>
        </div>    
</div>