<div class="col-lg-2 order-1 d-none d-lg-block">
<div class="list-group text-center">
  <a href="/topics/" class="list-group-item list-group-item-action active px-2">
    Hot Topics
  </a>
  <span class="list-group-item list-group-item-action px-2">
	<?php wp_tag_cloud('smallest=14&largest=28&unit=px&number=25&order=DESC&orderby=count&separator=</span><span class="list-group-item list-group-item-action px-2">');?>
  </span>
</div>
</div>

