<div class="jumbotron jumbotron-fluid">
     <div class="container">
  <h1 class="display-5"></h1>
  <p><?php bloginfo('description'); ?></p>
  <p><a class="btn btn-primary btn-lg" href="#">Learn more</a></p>
     </div>
</div> 