<div class="row ">
        <div class="col-12">
        <ol class="breadcrumb ">
  <li class="breadcrumb-item"><a href="/"><?php bloginfo('name'); ?></a></li>
  <li class="breadcrumb-item"><?php the_tags("<span class='badge badge-pill badge-info'>","</span> <span class='badge badge-pill badge-info'>","</span>"); ?></li>
  <li class="breadcrumb-item active"><?php the_title(); ?></li>
        </ol></div>
<div class='mx-auto'>
	<script async src="//pagead2.googlesyndication.com/pagead/js/adsbygoogle.js"></script>
<!-- pc 970*90 -->
<ins class="adsbygoogle"
     style="display:inline-block;width:970px;height:90px"
     data-ad-client="ca-pub-7560617178981988"
     data-ad-slot="7592697257"></ins>
<script>
(adsbygoogle = window.adsbygoogle || []).push({});
</script>
	</div>
</div>